Description
install_mvt is a wrapped function of py_install
in the reticulate package for installing the python package
mapbox_vector_tile, which will be installed in a virtual environment -
"r-mvt".
Usage
install_mvt(envname = "r-mvt", method = "auto")
Arguments
- envname
The name, or full path, of the environment
in which Python packages are to be installed.
- method
character, indicating installation method.